@@ -3,7 +3,7 @@
 # GNU General Public License v3.0+ (see LICENSE.txt or https://www.gnu.org/licenses/gpl-3.0.txt)
 
 ## @package pycross.guisettings
-# Stores a single global configurations object - CWSettings::settings
+# @brief Stores a single global configurations object - CWSettings::settings
 # together with methods to load from and save to compressed JSON files.
 from PyQt5 import QtGui, QtCore, QtWidgets
 import json, os, gzip
@@ -24,7 +24,7 @@ class CWSettings:
                             'act_undo', 'act_redo', 'SEP', 'act_edit', 'SEP', 'act_gen',
                             'act_clear', 'act_clear_wd', 'act_erase_wd',
                             'act_suggest', 'act_lookup', 'act_editclue', 'SEP', 'act_wsrc', 'act_info',
-                            'act_stats', 'act_print', 'SEP', 'act_config', 'act_update', 'act_help']
+                            'act_stats', 'act_print', 'SEP', 'act_config', 'act_update', 'act_help', 'act_whatsthis']
         },
     'cw_settings': {'timeout': 60.0, 'method': 'recurse', 'pos': 'N', 'log': None},
     'grid_style': {'scale': 100, 'show': True, 'line': QtCore.Qt.SolidLine, 'header': False,
